==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/jp.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: jp.php,v 1.8 2005/11/19 14:08:32 bigmichi1 Exp $

$charset                = 'euc-jp';
$text['title']          = 'ƥ';

$text['vitals']         = 'ƥư';
$text['hostname']       = 'ۥ̾';
$text['ip']             = 'IPɥ쥹';
$text['kversion']       = 'ͥС(uname)';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Ϣ³Ư(uptime)';
$text['users']          = '桼';
$text['loadavg']        = 'ɥ٥졼';

$text['hardware']       = 'ϡɥ';
$text['numcpu']         = 'CPU';
$text['cpumodel']       = 'CPUǥ';
$text['cpuspeed']       = 'å®(MHz)';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'å奵';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'PCIǥХ';
$text['ide']            = 'IDEǥХ';
$text['scsi']           = 'SCSIǥХ';
$text['usb']            = 'USBǥХ';

$text['netusage']       = 'ͥåȥѾ';
$text['device']         = '󥿥ե̾';
$text['received']       = '';
$text['sent']           = '';
$text['errors']         = '顼/ǽ';

$text['connections']    = '³Ƥͥåȥ³';

$text['memusage']       = 'Ѿ';
$text['phymem']         = 'ʪ';
$text['swap']           = 'ǥå';

$text['fs']             = 'ޥȺѤߥե륷ƥ';
$text['mount']          = 'ޥȥݥ';
$text['partition']      = 'ǥѡƥ';

$text['percent']        = 'ѳ';
$text['type']           = 'ե륷ƥ';
$text['free']           = '';
$text['used']           = '';
$text['size']           = '';
$text['totals']         = '';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ޤ';

$text['capacity']       = ''; 

$text['template']       = 'ǥ';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = 'Created by';

$text['days']           = '';
$text['hours']          = '';
$text['minutes']        = 'ʬ';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/jp.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: jp.php,v 1.11 2006/06/05 11:48:16 bigmichi1 Exp $

$charset                = 'euc-jp';
$text['title']          = 'ƥ';

$text['vitals']         = 'ƥư';
$text['hostname']       = 'ۥ̾';
$text['ip']             = 'IPɥ쥹';
$text['kversion']       = 'ͥС(uname)';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Ϣ³Ư(uptime)';
$text['users']          = '桼';
$text['loadavg']        = 'ɥ٥졼';

$text['hardware']       = 'ϡɥ';
$text['numcpu']         = 'CPU';
$text['cpumodel']       = 'CPUǥ';
$text['cpuspeed']       = 'å®(MHz)';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'å奵';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'PCIǥХ';
$text['ide']            = 'IDEǥХ';
$text['scsi']           = 'SCSIǥХ';
$text['usb']            = 'USBǥХ';

$text['netusage']       = 'ͥåȥѾ';
$text['device']         = '󥿥ե̾';
$text['received']       = '';
$text['sent']           = '';
$text['errors']         = '顼/ǽ';

$text['connections']    = '³Ƥͥåȥ³';

$text['memusage']       = 'Ѿ';
$text['phymem']         = 'ʪ';
$text['swap']           = 'ǥå';

$text['fs']             = 'ޥȺѤߥե륷ƥ';
$text['mount']          = 'ޥȥݥ';
$text['partition']      = 'ǥѡƥ';

$text['percent']        = 'ѳ';
$text['type']           = 'ե륷ƥ';
$text['free']           = '';
$text['used']           = '';
$text['size']           = '';
$text['totals']         = '';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'ޤ';

$text['capacity']       = ''; 

$text['template']       = 'ǥ';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = 'Created by';

$text['days']           = '';
$text['hours']          = '';
$text['minutes']        = 'ʬ';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

?>
